sqlobject.tests.test_events module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_events module

class `sqlobject.tests.test_events.` `EventTester`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = event_tester
  property `name`
  `q` = event_tester
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_events.EventTester`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'event_tester'

class `sqlobject.tests.test_events.` `InheritableEventTestA`(**kw)

  Bases: `sqlobject.inheritance.InheritableSQLObject`

  property `a`
  property `childName`
  `j` = inheritable_event_test_a
  `q` = inheritable_event_test_a
  class `sqlmeta`(instance)

    Bases: `sqlobject.inheritance.InheritableSQLMeta`

    `childClasses` = {'InheritableEventTestB': <class 'sqlobject.tests.test_events.InheritableEventTestB'>}
    `childName` = None
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass` = None
    `soClass`

      alias of `sqlobject.tests.test_events.InheritableEventTestA`

    `table` = 'inheritable_event_test_a'

class `sqlobject.tests.test_events.` `InheritableEventTestB`(**kw)

  Bases: `sqlobject.tests.test_events.InheritableEventTestA`

  property `a`
  property `b`
  property `childName`
  `j` = inheritable_event_test_b
  `q` = inheritable_event_test_b
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {'InheritableEventTestC': <class 'sqlobject.tests.test_events.InheritableEventTestC'>}
    `childName` = 'InheritableEventTestB'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.tests.test_events.InheritableEventTestA`

    `soClass`

      alias of `sqlobject.tests.test_events.InheritableEventTestB`

    `table` = 'inheritable_event_test_b'

class `sqlobject.tests.test_events.` `InheritableEventTestC`(**kw)

  Bases: `sqlobject.tests.test_events.InheritableEventTestB`

  property `b`
  property `c`
  property `childName`
  `j` = inheritable_event_test_c
  `q` = inheritable_event_test_c
  class `sqlmeta`(instance)

    Bases: `sqlobject.declarative.sqlmeta`

    `childClasses` = {}
    `childName` = 'InheritableEventTestC'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `parentClass`

      alias of `sqlobject.tests.test_events.InheritableEventTestB`

    `soClass`

      alias of `sqlobject.tests.test_events.InheritableEventTestC`

    `table` = 'inheritable_event_test_c'

`sqlobject.tests.test_events.` `make_listen`(signal, cls=None)

`sqlobject.tests.test_events.` `make_watcher`()

`sqlobject.tests.test_events.` `test_add_column`()

`sqlobject.tests.test_events.` `test_create`()

`sqlobject.tests.test_events.` `test_inheritance_row_created`()

`sqlobject.tests.test_events.` `test_row_create`()

`sqlobject.tests.test_events.` `test_row_destroy`()

`sqlobject.tests.test_events.` `test_row_destroyed`()

`sqlobject.tests.test_events.` `test_row_update`()

`sqlobject.tests.test_events.` `test_row_updated`()